=======
History
=======
0.3.0 (2020-10-5)
-------------------
* Turning pygwinc install into vendor inside gwent

0.2.1 (2020-10-5)
-------------------
* Update to ground-based SNR calculation
* Minor changes to snrplot functionality
* Changed fitting for WD background
* Misc bug fixing

0.2.0 (2020-4-29)
-------------------
* Major Changes to PTA detector setup
* Major Changes to snrplot
* Overhaul of tutorials
* Minor Changes to binary and snr functions
* Other Minor Changes sprinkled throughout 

0.1.16 (2020-1-19)
-------------------
* Removing install of pygwinc in setup.py
* pygwinc must now be manually installed 

0.1.15 (2020-1-18)
-------------------
* Including easy install of pygwinc

0.1.14 (2020-1-7)
-------------------
* Major addition of pygwinc
* Minor fixes to snr sampling and plotting

0.1.13 (2019-10-28)
-------------------
* Removing SNR Files in LoadFiles
* Fixing Error in PTA Initialization that Ignored User Input

0.1.12 (2019-10-8)
-------------------
* Adding New Files for NANOGrav
* Updating Loading from files for Detectors

0.1.11 (2019-09-19)
-------------------
* Fixing bugs and removing empty functionality

0.1.10 (2019-09-14)
-------------------
* Removed Python 2.7 support

0.1.0 (2019-09-04)
------------------

* First release on PyPI.
